@@ -1,10 +1,10 @@
-"""Run tests of the Nim Game
+"""Run tests of the Nim Game automatically
 
-Functions:
-    - play_full_game() plays one full game automatically, doing the moves for
-        both parties, according to their set error rates in the Nim instance
-    - run_many_games() creates a Nim instance and runs several games
-        automatically
+:func:`play_full_game` plays one full game automatically, doing the moves for
+both parties, according to their set error rates in the :class:`Nim` instance
+
+:func:`run_many_games` creates a :class:`Nim` instance and runs several games
+automatically
 """
 
 
@@ -16,17 +16,27 @@ def play_full_game(
         nim: Nim
 ) -> dict:
     """Play one full game
-
-    Create random heaps first. Then, figure out whether Computer is to start.
+    
+    There is no interaction, both players' moves are calculated by the program.
+    We just call the 1st player as Computer and the 2nd as Player.
+    
+    It creates random heaps first. Then, figures out whether Computer is to
+    start.
     This decision is based on the starting nimsum on Computer's favour, but with
     the Computer's error rate. Player and Computer take turns until the game
     ends. Moves are calculated with the same algorithm for the Computer and
     Player, but with different error rates.
+    
+    Args:
+        nim: the :class:`Nim` instance, created with the init arguments, like
+            `error_rate`
 
     Returns:
+        The result of the game.
         Keys in the returned dict:
+        
             - step_records: a list of statuses at each move
-            - computer_won: a bool stating whether the Computer won
+            - computer_won: a bool stating whether the "Computer" won
     """
     #create new random heaps
     nim.setup_heaps()
@@ -70,10 +80,11 @@ def run_many_games(
 ) -> None:
     """Run several games automatically
     
-    Create a Nim instance. Call play_full_game() for each game. Print a + when
-    the "Computer" wins, and - when the "Player" wins.
+    This function starts with creating a :class:`Nim` instance with setting the
+    required error rates. It then calls :func:`play_full_game` for each game. It
+    prints a + when the "Computer" wins, and - when the "Player" wins.
     
-    Then print the percentage the "Computer" won.
+    Then it prints the percentage the "Computer" won.
     
     Args:
         gamenum: the number of games to run
